@@ -1,9 +1,11 @@
-from typing import Type, List
+from typing import Type, List, Tuple, Any
+
+from django.db.models import Model
 from django.utils.encoding import force_text
 from jutil.dict import choices_label
 
 
-def get_object_or_none(cls, **kwargs):
+def get_object_or_none(cls: Any, **kwargs) -> Any:
     """
     Returns model instance or None if not found.
     :param cls: Class or queryset
@@ -17,7 +19,7 @@ def get_object_or_none(cls, **kwargs):
         return None
 
 
-def get_model_field_label_and_value(instance, field_name: str) -> (str, str):
+def get_model_field_label_and_value(instance, field_name: str) -> Tuple[str, str]:
     """
     Returns model field label and value (as text).
     :param instance: Model instance
@@ -51,20 +53,20 @@ def is_model_field_changed(instance, field_name: str) -> bool:
     return qs.filter(**params).first() is None
 
 
-def get_model_keys(instance, cls: Type or None = None,
+def get_model_keys(instance, cls: Type[Model] or None = None,
                    exclude_fields: tuple = ('id',), base_class_suffix: str = '_ptr') -> List[str]:
     if cls is None:
         cls = instance.__class__
     return [f.name for f in cls._meta.fields if f.name not in exclude_fields and not f.name.endswith(base_class_suffix)]
 
 
-def clone_model(instance, cls: Type or None = None, commit: bool = True,
+def clone_model(instance, cls: Type[Model] or None = None, commit: bool = True,
                 exclude_fields: tuple = ('id',), base_class_suffix: str = '_ptr', **kw):
     """
     Assigns model fields to new object. Ignores exclude_fields list and
     attributes ending with pointer suffix (default '_ptr')
     :param instance: Instance to copy
-    :param cls: Class name
+    :param cls: Class (opt)
     :param commit: Save or not
     :param exclude_fields: List of fields to exclude
     :param base_class_suffix: End of name for base class pointers, e.g. model Car(Vehicle) has implicit vehicle_ptr
